@@ -25,12 +25,11 @@ class Nexus:
     pom = PomFile(pom_file_location)
     artifact_version = pom.version()
     artifact_id = pom.artifact_id()
-    final_version = self.__final_version__(artifact_version)
 
-    maven_deploy_command = ("mvn deploy:deploy-file -Durl={3} " +
+    maven_deploy_command = ("mvn deploy:deploy-file -Durl={2} " +
                             "-DrepositoryId=deployment-pipeline -DgroupId=deployment-pipeline -DartifactId={0} -Dpackaging=war " +
-                            "-Dfile={0}-view/{0}-web-view/target/{0}.war -Dversion={4}"
-    ).format(artifact_id, artifact_version, self.build_number, self.base_url, final_version)
+                            "-Dfile={0}-view/{0}-web-view/target/{0}.war -Dversion={1}"
+    ).format(artifact_id, artifact_version,  self.base_url)
     print maven_deploy_command
 
     return_code = os.system(maven_deploy_command)
@@ -52,16 +51,6 @@ class Nexus:
     artifact_version = artifact_version_url.rpartition(project + "/")[2].replace("/", "")
     return (artifact_version_url + "{0}-{1}.war".format(project, artifact_version))
 
-  def __final_version__(self, artifact_version):
-    """
-     If build number is already in the version, then we should do nothing with it
-    """
-    if artifact_version.endswith("." + self.build_number):
-      return artifact_version
-    else:
-      return artifact_version + "." + self.build_number
-
-
 class NexusPageWithVersions(sgmllib.SGMLParser):
   hyperlinks = []
 
